/***************************************
 *  DSP1 Linker Command File
 *
 ***************************************/

/* -----------------------------------------------------*/
/* DSP memories											*/
/* 		L2 	- 288-KByte L2 cache						*/
/* 			  256-KByte configurable as cache or SRAM	*/
/* 			  32-KByte SRAM								*/
/* -----------------------------------------------------*/

/*-----------------------------------------------------------------------------*/

//-----------------------------------------------------------------------------

//-----------------------------------------------------------------------------

#define DSP1_L2_MEM_ORG                 (0x800000)      //Total DSP_L2 Memory Start Address
#define DSP1_L2_MEM_SIZE                (0x48000)       //Total DSP_L2 Memory Size

#define DSP1_L2_CONFIGURED_CACHE_SIZE   (0x40000)       //256K -- Amount of L2 that is configured as cache

#define DSP1_L2_RAM_MEM_START           (DSP1_L2_MEM_ORG)
#define DSP1_L2_RAM_MEM_LEN             ((DSP1_L2_MEM_SIZE)-(DSP1_L2_CONFIGURED_CACHE_SIZE))
#define DSP1_L2_RAM_MEM_END             ((DSP1_RAM_MEM_START)+(DSP1_RAM_MEM_LEN))

//-----------------------------------------------------------------------------

#define DSP1_DDR_CODE_MEM_START         (0xec801000)
#define DSP1_DDR_CODE_MEM_LEN           (0x20000)
#define DSP1_DDR_CODE_MEM_END           ((DSP1_DDR_CODE_MEM_START)+(DSP1_DDR_CODE_MEM_LEN))

#define DSP1_DDR_DATA_MEM_START         (DSP1_DDR_CODE_MEM_END)
#define DSP1_DDR_DATA_MEM_LEN           (0x600000)
#define DSP1_DDR_DATA_MEM_END           ((DSP1_DDR_DATA_MEM_START)+(DSP1_DDR_DATA_MEM_LEN))

#define DDR_APP_PROCESSED_DATA_MEM_START	(0xca900000)
#define DDR_APP_PROCESSED_DATA_MEM_LEN      (0x12500000)

//----------------------------

//#define DSP1_DDR_ALLOC_MEM_END          (DSP1_DDR_DATA_MEM_END)

//#if ((DSP1_DDR_ALLOC_MEM_END)>(DDR_DSP1_MEM_END))
//#error "Error - DSP1 DDR Allocations Exceeds Available Memory !"
//#endif

//----------------------------

//-----------------------------------------------------------------------------

/*----------------------------------------------------------------------------*/

/* SPECIFY THE DSP1 MEMORY MAP */

-c
-heap  0x2000
-stack 0x2000

MEMORY
{
    L2SRAM_MEM (RWX):           		org = (DSP1_L2_RAM_MEM_START)       		,   len = (DSP1_L2_RAM_MEM_LEN)

    DSP1_DDR_CODE_MEM (RWIX):   		org = (DSP1_DDR_CODE_MEM_START)     		,   len = (DSP1_DDR_CODE_MEM_LEN)

    DSP1_DDR_DATA_MEM (RWIX):   		org = (DSP1_DDR_DATA_MEM_START)     		,   len = (DSP1_DDR_DATA_MEM_LEN)

    DDR_APP_PROCESSED_DATA_MEM (RWIX):	org = (DDR_APP_PROCESSED_DATA_MEM_START)	,   len = (DDR_APP_PROCESSED_DATA_MEM_LEN)

}

SECTIONS
{
    .vects:                     > L2SRAM_MEM
    .text:_init_regs            > L2SRAM_MEM
    .text:_c_int00:             > DSP1_DDR_CODE_MEM     align = 0x400   //DSP Entry point must be aligned to 0x400
    .text:                      > DSP1_DDR_CODE_MEM

    .cinit:                     > DSP1_DDR_DATA_MEM
    .data:                      > DSP1_DDR_DATA_MEM
    .const:                     > DSP1_DDR_DATA_MEM
    .cio:                       > DSP1_DDR_DATA_MEM
    .switch:                    > DSP1_DDR_DATA_MEM
    .sysmem:                    > DSP1_DDR_DATA_MEM
    .far:                       > DSP1_DDR_DATA_MEM
    .fardata:                   > DSP1_DDR_DATA_MEM

    text_L2:                    > L2SRAM_MEM
    data_L2:                    > L2SRAM_MEM

    .l2_int:                    > L2SRAM_MEM

    GROUP (NEAR_DP_GROUP)
    {
        .neardata:
        .rodata:
        .bss:
    } > L2SRAM_MEM

    .stack:                           > L2SRAM_MEM

    .traceBuffer:   type=(NOLOAD)     > DSP1_DDR_DATA_MEM

    //--------------------------------------------------------

    .appProcessedData.processedData > DDR_APP_PROCESSED_DATA_MEM

    //--------------------------------------------------------

}
